from typing import Iterator

import re
import pathlib
import json

import black

from .version import __version__

def gen_notebook_files_in_dir(path: pathlib.Path) -> Iterator[pathlib.Path]:

    return path.glob("**/*.ipynb")

def format_notebook_content(path: pathlib.Path) -> dict:
    content = path.read_text()
    nb = json.loads(content)

    for cell in nb["cells"]:
        try:
            string = "".join(cell["source"])
            formatted_string = black.format_str(string, line_length=black.DEFAULT_LINE_LENGTH)
            cell["source"] = [s + "\n" for s in formatted_string.split("\n")][:-1]
        except black.InvalidInput:
            pass

    return nb



import json
import pathlib
import sys

import blackbook


def main(path=None):
    if path is None:
        path = pathlib.Path(sys.argv[1])

    for notebook_path in blackbook.gen_notebook_files_in_dir(path):
        nb = blackbook.format_notebook_content(notebook_path)

        notebook_path.write_text(json.dumps(nb))

if __name__ == '__main__':
    main()



from setuptools import setup, find_packages
import unittest
import doctest
import os

requirements = ["black>=18.9b0"]

exec(open("src/blackbook/version.py", "r").read())

setup(
    name="blackbook",
    version=__version__,
    install_requires=requirements,
    author="Nikoleta Glynatsi, Vince Knight, Henry Wilde",
    author_email=("glynatsine@cardiff.ac.uk"),
    packages=find_packages("src"),
    package_dir={"": "src"},
    url="",
    license="The MIT License (MIT)",
    description="`Black` for Jupyter notebooks.",
    entry_points={"console_scripts": "blackbook=blackbook.__main__:main"},
)
